==> gpxsee-debug-14.0-1-x86_64.pkg.tar.zst: usr/src/debug/gpxsee/GPXSee-14.0/src/map/onlinemap.h <==
#ifndef ONLINEMAP_H
#define ONLINEMAP_H

#include <QImageReader>
#include <QPixmap>
#include <QtConcurrent>
#include "common/range.h"
#include "common/rectc.h"
#include "map.h"
#include "mvtstyle.h"
#include "tileloader.h"

class OnlineMapTile
{
public:
	OnlineMapTile(const QPoint &xy, const QString &file, int zoom, int overzoom,
	  int scaledSize, int style, const QString &key) : _zoom(zoom),
	  _overzoom(overzoom), _scaledSize(scaledSize), _style(style), _xy(xy),
	  _file(file), _key(key) {}

	void load()
	{
		if (_scaledSize) {
			QByteArray format(QByteArray::number(_zoom)
			  + ';' + QByteArray::number(_overzoom)
			  + ';' + QByteArray::number(_style));
			QImageReader reader(_file, format);
			reader.setScaledSize(QSize(_scaledSize, _scaledSize));
			_pixmap = QPixmap::fromImageReader(&reader);
		} else {
			QImageReader reader(_file);
			_pixmap = QPixmap::fromImageReader(&reader);
		}
	}

	const QPoint &xy() const {return _xy;}
	const QPixmap &pixmap() const {return _pixmap;}
	const QString &key() const {return _key;}

private:
	int _zoom;
	int _overzoom;
	int _scaledSize;
	int _style;
	QPoint _xy;
	QString _file;
	QString _key;
	QPixmap _pixmap;
};

class OnlineMapJob : public QObject
{
	Q_OBJECT

public:
	OnlineMapJob(const QList<OnlineMapTile> &tiles) : _tiles(tiles) {}

	void run()
	{
		connect(&_watcher, &QFutureWatcher<void>::finished, this,
		  &OnlineMapJob::handleFinished);
		_future = QtConcurrent::map(_tiles, &OnlineMapTile::load);
		_watcher.setFuture(_future);
	}
	void cancel(bool wait)
	{
		_future.cancel();
		if (wait)
			_future.waitForFinished();
	}
	const QList<OnlineMapTile> &tiles() const {return _tiles;}

signals:
	void finished(OnlineMapJob *job);

private slots:
	void handleFinished() {emit finished(this);}

private:
	QFutureWatcher<void> _watcher;
	QFuture<void> _future;
	QList<OnlineMapTile> _tiles;
};

class OnlineMap : public Map
{
	Q_OBJECT

public:
	OnlineMap(const QString &fileName, const QString &name, const QString &url,
	  const Range &zooms, const RectC &bounds, qreal tileRatio,
	  const QList<HTTPHeader> &headers, int tileSize, bool mvt, bool invertY,
	  bool quadTiles, const QStringList &layers, QObject *parent = 0);

	QString name() const {return _name;}

	QRectF bounds();
	RectC llBounds() {return _bounds;}
	qreal resolution(const QRectF &rect);

	int zoom() const {return _zoom;}
	void setZoom(int zoom) {_zoom = zoom;}
	int zoomFit(const QSize &size, const RectC &rect);
	int zoomIn();
	int zoomOut();

	QPointF ll2xy(const Coordinates &c);
	Coordinates xy2ll(const QPointF &p);

	void draw(QPainter *painter, const QRectF &rect, Flags flags);

	void load(const Projection &in, const Projection &out, qreal deviceRatio,
	  bool hidpi, int style, int layer);
	void unload();
	void clearCache();

	QStringList styles(int &defaultStyle) const;

private slots:
	void jobFinished(OnlineMapJob *job);

private:
	int defaultStyle(const QStringList &vectorLayers);
	int limitZoom(int zoom) const;
	qreal tileSize() const;
	qreal coordinatesRatio() const;
	qreal imageRatio() const;
	QPoint tileCoordinates(int x, int y, int zoom) const;
	QPointF tilePos(const QPointF &tl, const QPoint &tc, const QPoint &tile,
	  unsigned overzoom) const;
	void drawTile(QPainter *painter, QPixmap &pixmap, QPointF &tp);
	bool isRunning(const QString &key) const;
	void runJob(OnlineMapJob *job);
	void removeJob(OnlineMapJob *job);
	void cancelJobs(bool wait);

	TileLoader *_tileLoader;
	QString _name;
	Range _zooms;
	RectC _bounds;
	int _zoom;
	int _tileSize;
	int _baseZoom;
	qreal _mapRatio, _tileRatio;
	bool _mvt;
	int _scaledSize;
	bool _invertY;
	QList<MVTStyle> _styles;
	int _style;

	QList<OnlineMapJob*> _jobs;
};

#endif // ONLINEMAP_H

==> gpxsee-debug-15.5-1-x86_64.pkg.tar.zst: usr/src/debug/gpxsee/GPXSee-15.5/src/map/onlinemap.h <==
#ifndef ONLINEMAP_H
#define ONLINEMAP_H

#include "common/range.h"
#include "common/rectc.h"
#include "tileloader.h"
#include "mvtjob.h"
#include "map.h"

class QPixmap;

class OnlineMap : public Map
{
	Q_OBJECT

public:
	OnlineMap(const QString &fileName, const QString &name,
	  const QStringList &url, const Range &zooms, const RectC &bounds,
	  qreal tileRatio, const QList<HTTPHeader> &headers, int tileSize,
	  bool mvt, bool invertY, bool quadTiles, const QStringList &layers,
	  QObject *parent = 0);

	QString name() const {return _name;}

	QRectF bounds();
	RectC llBounds() {return _bounds;}
	qreal resolution(const QRectF &rect);

	int zoom() const {return _zoom;}
	void setZoom(int zoom);
	int zoomFit(const QSize &size, const RectC &rect);
	int zoomIn();
	int zoomOut();

	QPointF ll2xy(const Coordinates &c);
	Coordinates xy2ll(const QPointF &p);

	void draw(QPainter *painter, const QRectF &rect, Flags flags);

	void load(const Projection &in, const Projection &out, qreal deviceRatio,
	  bool hidpi, bool hillShading, int style, int layer);
	void unload();
	void clearCache();

	QStringList styles(int &defaultStyle) const;
	bool hillShading() const;

private slots:
	void jobFinished(MVTJob *job);

private:
	int limitZoom(int zoom) const;
	qreal tileSize() const;
	QPoint tileCoordinates(int x, int y, int zoom) const;
	QPointF tilePos(const QPointF &tl, const QPoint &tc, const QPoint &tile,
	  unsigned overzoom) const;
	void drawTile(QPainter *painter, QPixmap &pixmap, QPointF &tp);

	QString key(int zoom, const QPoint &xy) const;
	bool isRunning(int zoom, const QPoint &xy) const;
	void runJob(MVTJob *job);
	void removeJob(MVTJob *job);
	void cancelJobs(bool wait);

	const MVT::Style *defaultStyle() const;

	TileLoader *_tileLoader;
	QString _name;
	Range _zooms;
	RectC _bounds;
	int _zoom;
	int _tileSize;
	int _baseZoom;
	qreal _mapRatio, _tileRatio;
	bool _mvt, _hillShading, _invertY;
	const MVT::Style *_style;
	QStringList _layers;

	qreal _factor;
	qreal _coordinatesRatio;

	QList<MVTJob*> _jobs;
};

#endif // ONLINEMAP_H
